%%
%% This is file `childdoc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% childdoc.dtx  (with options: `package')
%% 
%% Copyright (C) 2017-2018 Niklas Beisert
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
\ifdefined\childdocmain\endinput\fi
\ProvidesFile{childdoc.def}[2018/12/30 v2.0 child document driver]

\newif\ifchilddoc
\newif\ifchilddocmanual

\edef\childdocname{\scantokens\expandafter{\jobname\noexpand}}
\let\childdocjob\childdocname

\newcommand{\childdocdisable}
{
  \renewcommand{\childdocmain}[1]{\renewcommand{\childdocmain}[1]{\endinput}}
  \renewcommand{\childdocof}[1]{}
  \renewcommand{\childdocby}[2][]{}
  \renewcommand{\childdocforward}[2][]{}
  \renewcommand{\childdocdisable}{}
}

\newcommand{\childdocmain}[1]
{
  \childdocdisable\childdocmain{}
  \if?#1?\else
    \begingroup
      \def\childdoctmp{#1}
      \ifx\childdoctmp\childdocname
        \def\childdoctmp{}
      \else
        \def\childdoctmp
        {
          \childdoctrue
          \includeonly{\childdocname}
          \def\childdocjob{#1}
          \def\jobname{#1}
        }
      \fi
      \expandafter
    \endgroup
    \childdoctmp
  \fi
}

\newcommand{\childdocof}[1]
{
  \childdocdisable
  \childdoctrue
  \includeonly{\childdocname}
  \def\jobname{#1}
  \def\childdocjob{#1}
  \input{#1}
}

\newcommand{\childdocby}[2][]
{
  \childdocdisable
  \childdoctrue
  \childdocmanualtrue
  \if?#1?\else
    \def\jobname{#2}
  \fi
  \def\childdocjob{#2}
  \input{#2}
  \endinput
}

\newcommand{\childdocforward}[2][]
{
  \begingroup
    \if?#1?
      \def\childdoctmp
      {
        \def\childdocname{#2}
        \def\childdocjob{#2}
        \def\jobname{#2}
        \input{#2}
        \endinput
      }
    \else
      \def\childdoctmp
      {
        \childdocdisable
        \def\childdocname{#2}
        \childdoctrue
        \includeonly{#2}
        \def\childdocjob{#1}
        \def\jobname{#1}
        \input{#1}
        \endinput
      }
    \fi
    \expandafter
  \endgroup
  \childdoctmp
}

\newcommand{\childdocforwardprefix}[3][]
{
  \begingroup
    \def\childdocextract #2##1~~~{\def\childdoctmp{\childdocforward[#1]{#3##1}}}
    \expandafter\childdocextract\childdocname~~~
    \expandafter
  \endgroup
  \childdoctmp
}

\newcommand{\childdoc}{\childdocmain}

\newcommand{\childdocredirect}[2][]
{
  \begingroup
    \if?#1?
      \def\childdoctmp{\childdocforward{#2}}
    \else
      \def\childdoctmp{\childdocforwardprefix{#1}{#2}}
    \fi
    \expandafter
  \endgroup
  \childdoctmp
}

\endinput
%%
%% End of file `childdoc.def'.
